scoretools.Chord
================

.. abjad-lineage:: abjad.tools.scoretools.Chord.Chord

.. autoclass:: abjad.tools.scoretools.Chord.Chord

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.scoretools.Chord.Chord.note_heads
      ~abjad.tools.scoretools.Chord.Chord.written_duration
      ~abjad.tools.scoretools.Chord.Chord.written_pitches
      ~abjad.tools.scoretools.Chord.Chord.__copy__
      ~abjad.tools.scoretools.Chord.Chord.__eq__
      ~abjad.tools.scoretools.Chord.Chord.__format__
      ~abjad.tools.scoretools.Chord.Chord.__illustrate__
      ~abjad.tools.scoretools.Chord.Chord.__mul__
      ~abjad.tools.scoretools.Chord.Chord.__ne__
      ~abjad.tools.scoretools.Chord.Chord.__repr__
      ~abjad.tools.scoretools.Chord.Chord.__rmul__
      ~abjad.tools.scoretools.Chord.Chord.__str__

Bases
-----

- :py:class:`scoretools.Leaf <abjad.tools.scoretools.Leaf.Leaf>`

- :py:class:`scoretools.Component <abjad.tools.scoretools.Component.Component>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read/write properties
---------------------

.. autoattribute:: abjad.tools.scoretools.Chord.Chord.note_heads
   :noindex:

.. autoattribute:: abjad.tools.scoretools.Chord.Chord.written_duration
   :noindex:

.. autoattribute:: abjad.tools.scoretools.Chord.Chord.written_pitches
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.scoretools.Chord.Chord.__copy__
   :noindex:

.. automethod:: abjad.tools.scoretools.Chord.Chord.__eq__
   :noindex:

.. automethod:: abjad.tools.scoretools.Chord.Chord.__format__
   :noindex:

.. automethod:: abjad.tools.scoretools.Chord.Chord.__illustrate__
   :noindex:

.. automethod:: abjad.tools.scoretools.Chord.Chord.__mul__
   :noindex:

.. automethod:: abjad.tools.scoretools.Chord.Chord.__ne__
   :noindex:

.. automethod:: abjad.tools.scoretools.Chord.Chord.__repr__
   :noindex:

.. automethod:: abjad.tools.scoretools.Chord.Chord.__rmul__
   :noindex:

.. automethod:: abjad.tools.scoretools.Chord.Chord.__str__
   :noindex:
